---
---qaction
---
CREATE TABLE qaction
(
  qaction_sid serial NOT NULL,
  "action" varchar(40) NOT NULL,
  CONSTRAINT qaction_sid PRIMARY KEY (qaction_sid),
  CONSTRAINT qaction_action_key UNIQUE ("action")
) 
WITHOUT OIDS;

INSERT INTO qaction (action) VALUES ('ABANDON');
INSERT INTO qaction (action) VALUES ('AGENTDUMP');
INSERT INTO qaction (action) VALUES ('AGENTLOGIN');
INSERT INTO qaction (action) VALUES ('AGENTCALLBACKLOGIN');
INSERT INTO qaction (action) VALUES ('AGENTLOGOFF');
INSERT INTO qaction (action) VALUES ('AGENTCALLBACKLOGOFF');
INSERT INTO qaction (action) VALUES ('COMPLETEAGENT');
INSERT INTO qaction (action) VALUES ('COMPLETECALLER');
INSERT INTO qaction (action) VALUES ('CONFIGRELOAD');
INSERT INTO qaction (action) VALUES ('CONNECT');
INSERT INTO qaction (action) VALUES ('ENTERQUEUE');
INSERT INTO qaction (action) VALUES ('EXITWITHKEY');
INSERT INTO qaction (action) VALUES ('EXITWITHTIMEOUT');
INSERT INTO qaction (action) VALUES ('QUEUESTART');
INSERT INTO qaction (action) VALUES ('SYSCOMPAT');
INSERT INTO qaction (action) VALUES ('TRANSFER');


---
---qagent
---
CREATE TABLE qagent
(
  qagent_sid serial NOT NULL,
  agent varchar(40) NOT NULL,
  CONSTRAINT qagent_sid PRIMARY KEY (qagent_sid),
  CONSTRAINT qagent_agent_key UNIQUE (agent)
) 
WITHOUT OIDS;


---
---qname
---
CREATE TABLE qname
(
  qname_sid serial NOT NULL,
  queue varchar(40) NOT NULL,
  CONSTRAINT qname_sid PRIMARY KEY (qname_sid),
  CONSTRAINT qname_queue_key UNIQUE (queue)
) 
WITHOUT OIDS;


---
---queue_stats
---
CREATE TABLE queue_stats
(
  queue_stats_sid serial NOT NULL,
  qname int2,
  qagent int2,
  qaction int2,
  info1 varchar(80),
  info2 varchar(80),
  info3 varchar(80),
  datetime timestamptz NOT NULL,
  call_datetime timestamptz,
  call_id int4,
  action_duration int4,
  CONSTRAINT queue_stats_sid PRIMARY KEY (queue_stats_sid),
  CONSTRAINT "$1" FOREIGN KEY (qname) REFERENCES qname (qname_sid) MATCH SIMPLE ON UPDATE CASCADE ON DELETE RESTRICT,
  CONSTRAINT "$2" FOREIGN KEY (qagent) REFERENCES qagent (qagent_sid) MATCH SIMPLE ON UPDATE CASCADE ON DELETE RESTRICT,
  CONSTRAINT "$3" FOREIGN KEY (qaction) REFERENCES qaction (qaction_sid) MATCH SIMPLE ON UPDATE CASCADE ON DELETE RESTRICT
) 
WITHOUT OIDS;


---
---accountcode
---
CREATE TABLE accountcode
(
  accountcode_sid serial NOT NULL,
  accountcode varchar(40) NOT NULL,
  CONSTRAINT accountcode_sid PRIMARY KEY (accountcode_sid),
  CONSTRAINT accountcode_accountcode_key UNIQUE (accountcode)
) 
WITHOUT OIDS;


---
---amaflags
---
CREATE TABLE amaflags
(
  amaflags_sid serial NOT NULL,
  amaflags varchar(30) NOT NULL,
  CONSTRAINT amaflags_sid PRIMARY KEY (amaflags_sid)
) 
WITHOUT OIDS;


---
---disposition
---
CREATE TABLE disposition
(
  disposition_sid serial NOT NULL,
  disposition varchar(10) NOT NULL,
  CONSTRAINT disposition_sid PRIMARY KEY (disposition_sid)
) 
WITHOUT OIDS;


---
---cdr
---
CREATE TABLE cdr
(
  cdr_sid serial NOT NULL,
  accountcode varchar(20),
  src varchar(80),
  dst varchar(80),
  dcontext varchar(80),
  clid varchar(80),
  channel varchar(80),
  destchannel varchar(80),
  lastapp varchar(80),
  lastdata varchar(80),
  "start" timestamp,
  answer timestamp,
  "end" timestamp,
  duration int4,
  billsec int4,
  disposition int2,
  amaflags int2,
  userfield varchar(255),
  uniqueid varchar(32),
  CONSTRAINT cdr_sid PRIMARY KEY (cdr_sid),
  CONSTRAINT cdr_amaflags_fkey FOREIGN KEY (amaflags)
      REFERENCES amaflags (amaflags_sid) MATCH SIMPLE
      ON UPDATE CASCADE ON DELETE RESTRICT,
  CONSTRAINT cdr_disposition_fkey FOREIGN KEY (disposition)
      REFERENCES disposition (disposition_sid) MATCH SIMPLE
      ON UPDATE CASCADE ON DELETE RESTRICT
) 
WITHOUT OIDS;